[![Travis](https://travis-ci.com/tdegeus/GooseHDF5.svg?branch=master)](https://travis-ci.com/tdegeus/GooseHDF5)
[![Build status](https://ci.appveyor.com/api/projects/status/6cpocg96lf7v6djd?svg=true)](https://ci.appveyor.com/project/tdegeus/goosehdf5)
[![Documentation Status](https://readthedocs.org/projects/goosehdf5/badge/?version=latest)](http://goosehdf5.readthedocs.io/en/latest/?badge=latest)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/goosehdf5.svg)](https://anaconda.org/conda-forge/goosehdf5)

# GooseHDF5

A simple wrapper around `h5py` providing some useful Python function and some command-line tools.

Documentation [GooseHDF5.readthedocs.io](http://GooseHDF5.readthedocs.io)

# Disclaimer

This library is free to use under the 
[MIT license](https://github.com/tdegeus/GooseHDF5/blob/master/LICENSE). 
Any additions are very much appreciated, in terms of suggested functionality, code, 
documentation, testimonials, word of mouth advertisement, .... 
Bug reports or feature requests can be filed on 
[GitHub](https://github.com/tdegeus/GooseHDF5). 
As always, the code comes with no guarantee. 
None of the developers can be held responsible for possible mistakes.

Download: 
[.zip file](https://github.com/tdegeus/GooseHDF5/zipball/master) | 
[.tar.gz file](https://github.com/tdegeus/GooseHDF5/tarball/master).

(c - [MIT](https://github.com/tdegeus/GooseHDF5/blob/master/LICENSE)) 
T.W.J. de Geus (Tom) | tom@geus.me | www.geus.me | 
[github.com/tdegeus/GooseHDF5](https://github.com/tdegeus/GooseHDF5)

